==> synergy-1.2.4.tar.gz: synergy-1.2.4/cmd/launcher/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by launcher.rc
//
#define IDS_ERROR                       1
#define IDS_INVALID_SCREEN_NAME         2
#define IDS_DUPLICATE_SCREEN_NAME       3
#define IDS_SCREEN_NAME_IS_ALIAS        4
#define IDS_VERIFY                      5
#define IDS_UNSAVED_DATA_REALLY_QUIT    6
#define IDS_UNKNOWN_SCREEN_NAME         7
#define IDS_INVALID_PORT                8
#define IDS_SAVE_FAILED                 9
#define IDS_STARTUP_FAILED              10
#define IDS_STARTED_TITLE               11
#define IDS_STARTED                     12
#define IDS_INSTALL_FAILED              13
#define IDS_UNINSTALL_TITLE             14
#define IDS_UNINSTALLED                 15
#define IDS_UNINSTALL_FAILED            16
#define IDS_CLIENT                      17
#define IDS_SERVER                      18
#define IDS_AUTOSTART_PERMISSION_SYSTEM 19
#define IDS_AUTOSTART_PERMISSION_USER   20
#define IDS_AUTOSTART_PERMISSION_NONE   21
#define IDS_AUTOSTART_INSTALLED_SYSTEM  22
#define IDS_AUTOSTART_INSTALLED_USER    23
#define IDS_AUTOSTART_INSTALLED_NONE    24
#define IDS_INSTALL_LABEL               25
#define IDS_UNINSTALL_LABEL             26
#define IDS_INSTALL_GENERIC_ERROR       27
#define IDS_UNINSTALL_GENERIC_ERROR     28
#define IDS_INSTALL_TITLE               29
#define IDS_INSTALLED_SYSTEM            30
#define IDS_INSTALLED_USER              31
#define IDS_UNINSTALLED_SYSTEM          32
#define IDS_UNINSTALLED_USER            33
#define IDS_INVALID_SERVER_NAME         34
#define IDS_TITLE                       35
#define IDS_SERVER_IS_CLIENT            36
#define IDS_ADD_SCREEN                  37
#define IDS_EDIT_SCREEN                 38
#define IDS_INVALID_TIME                39
#define IDS_ERROR_CODE                  39
#define IDS_AUTOSTART_PERMISSION_ALL    40
#define IDS_INVALID_INTERFACE_NAME      41
#define IDS_INVALID_CORNER_SIZE         42
#define IDD_MAIN                        101
#define IDD_ADD                         102
#define IDD_WAIT                        103
#define IDI_SYNERGY                     104
#define IDD_AUTOSTART                   105
#define IDD_ADVANCED_OPTIONS            106
#define IDD_GLOBAL_OPTIONS              107
#define IDC_MAIN_CLIENT_RADIO           1000
#define IDC_MAIN_SERVER_RADIO           1001
#define IDC_MAIN_CLIENT_SERVER_NAME_EDIT 1002
#define IDC_MAIN_ADVANCED_NAME_EDIT     1006
#define IDC_MAIN_ADVANCED_PORT_EDIT     1008
#define IDC_MAIN_TEST                   1009
#define IDC_MAIN_SAVE                   1010
#define IDC_MAIN_CLIENT_SERVER_NAME_LABEL 1011
#define IDC_MAIN_SERVER_SCREENS_LIST    1012
#define IDC_MAIN_SERVER_SCREENS_LABEL   1013
#define IDC_MAIN_SERVER_LAYOUT_LABEL    1014
#define IDC_MAIN_SERVER_ADD_BUTTON      1018
#define IDC_MAIN_SERVER_EDIT_BUTTON     1019
#define IDC_ADD_SCREEN_NAME_EDIT        1020
#define IDC_MAIN_SERVER_REMOVE_BUTTON   1020
#define IDC_ADD_ALIASES_EDIT            1021
#define IDC_MAIN_SERVER_OPTIONS_BUTTON  1021
#define IDC_MAIN_SERVER_LEFT_COMBO      1022
#define IDC_MAIN_SERVER_RIGHT_COMBO     1023
#define IDC_MAIN_SERVER_TOP_COMBO       1024
#define IDC_MAIN_SERVER_BOTTOM_COMBO    1025
#define IDC_MAIN_SERVER_LEFT_LABEL      1026
#define IDC_MAIN_SERVER_RIGHT_LABEL     1027
#define IDC_MAIN_SERVER_TOP_LABEL       1028
#define IDC_MAIN_SERVER_BOTTOM_LABEL    1029
#define IDC_MAIN_UNINSTALL              1030
#define IDC_AUTOSTART_INSTALLED_MSG     1031
#define IDC_AUTOSTART_PERMISSION_MSG    1032
#define IDC_AUTOSTART_INSTALL_USER      1033
#define IDC_AUTOSTART_INSTALL_SYSTEM    1034
#define IDC_MAIN_AUTOSTART              1035
#define IDC_MAIN_OPTIONS                1036
#define IDC_ADD_HD_CAPS_CHECK           1037
#define IDC_MAIN_ADVANCED               1037
#define IDC_ADD_HD_NUM_CHECK            1038
#define IDC_ADVANCED_NAME_EDIT          1038
#define IDC_ADVANCED_PORT_EDIT          1039
#define IDC_ADD_HD_SCROLL_CHECK         1039
#define IDC_MAIN_DEBUG                  1040
#define IDC_ADVANCED_INTERFACE_EDIT     1040
#define IDC_GLOBAL_DELAY_CHECK          1041
#define IDC_GLOBAL_DELAY_TIME           1042
#define IDC_GLOBAL_TWO_TAP_CHECK        1043
#define IDC_ADD_MOD_SHIFT               1043
#define IDC_GLOBAL_TWO_TAP_TIME         1044
#define IDC_ADD_MOD_CTRL                1044
#define IDC_ADD_MOD_ALT                 1045
#define IDC_GLOBAL_HEARTBEAT_CHECK      1045
#define IDC_ADD_MOD_META                1046
#define IDC_GLOBAL_HEARTBEAT_TIME       1046
#define IDC_ADD_MOD_SUPER               1047
#define IDC_GLOBAL_SCREENSAVER_SYNC     1047
#define IDC_GLOBAL_RELATIVE_MOVES       1048
#define IDC_ADVANCED_DEFAULTS           1049
#define IDC_GLOBAL_LEAVE_FOREGROUND     1049
#define IDC_ADD_DC_SIZE                 1052
#define IDC_ADD_DC_TOP_LEFT             1053
#define IDC_ADD_DC_TOP_RIGHT            1054
#define IDC_ADD_DC_BOTTOM_LEFT          1055
#define IDC_ADD_DC_BOTTOM_RIGHT         1056

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        110
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1057
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> synergy-1.2.5.tar.gz: synergy-1.2.5/cmd/launcher/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by launcher.rc
//
#define IDS_ERROR                       1
#define IDS_INVALID_SCREEN_NAME         2
#define IDS_DUPLICATE_SCREEN_NAME       3
#define IDS_SCREEN_NAME_IS_ALIAS        4
#define IDS_VERIFY                      5
#define IDS_UNSAVED_DATA_REALLY_QUIT    6
#define IDS_UNKNOWN_SCREEN_NAME         7
#define IDS_INVALID_PORT                8
#define IDS_SAVE_FAILED                 9
#define IDS_STARTUP_FAILED              10
#define IDS_STARTED_TITLE               11
#define IDS_STARTED                     12
#define IDS_INSTALL_FAILED              13
#define IDS_UNINSTALL_TITLE             14
#define IDS_UNINSTALLED                 15
#define IDS_UNINSTALL_FAILED            16
#define IDS_CLIENT                      17
#define IDS_SERVER                      18
#define IDS_AUTOSTART_PERMISSION_SYSTEM 19
#define IDS_AUTOSTART_PERMISSION_USER   20
#define IDS_AUTOSTART_PERMISSION_NONE   21
#define IDS_AUTOSTART_INSTALLED_SYSTEM  22
#define IDS_AUTOSTART_INSTALLED_USER    23
#define IDS_AUTOSTART_INSTALLED_NONE    24
#define IDS_INSTALL_LABEL               25
#define IDS_UNINSTALL_LABEL             26
#define IDS_INSTALL_GENERIC_ERROR       27
#define IDS_UNINSTALL_GENERIC_ERROR     28
#define IDS_INSTALL_TITLE               29
#define IDS_INSTALLED_SYSTEM            30
#define IDS_INSTALLED_USER              31
#define IDS_UNINSTALLED_SYSTEM          32
#define IDS_UNINSTALLED_USER            33
#define IDS_INVALID_SERVER_NAME         34
#define IDS_TITLE                       35
#define IDS_SERVER_IS_CLIENT            36
#define IDS_ADD_SCREEN                  37
#define IDS_EDIT_SCREEN                 38
#define IDS_INVALID_TIME                39
#define IDS_ERROR_CODE                  39
#define IDS_AUTOSTART_PERMISSION_ALL    40
#define IDS_INVALID_INTERFACE_NAME      41
#define IDS_INVALID_CORNER_SIZE         42
#define IDS_NEW_LINK                    43
#define IDS_SIDE_LEFT                   44
#define IDS_SIDE_RIGHT                  45
#define IDS_SIDE_TOP                    46
#define IDS_SIDE_BOTTOM                 47
#define IDS_LINK_FORMAT                 48
#define IDS_LINK_INTERVAL_FORMAT        49
#define IDS_EDGE_LEFT                   50
#define IDS_EDGE_RIGHT                  51
#define IDS_EDGE_TOP                    52
#define IDS_EDGE_BOTTOM                 53
#define IDS_AUTOSTART_SAVE_FAILED       54
#define IDD_MAIN                        101
#define IDD_ADD                         102
#define IDD_WAIT                        103
#define IDI_SYNERGY                     104
#define IDD_AUTOSTART                   105
#define IDD_ADVANCED_OPTIONS            106
#define IDD_GLOBAL_OPTIONS              107
#define IDD_SCREENS_LINKS               110
#define IDC_MAIN_CLIENT_RADIO           1000
#define IDC_MAIN_SERVER_RADIO           1001
#define IDC_MAIN_CLIENT_SERVER_NAME_LABEL 1002
#define IDC_MAIN_CLIENT_SERVER_NAME_EDIT 1003
#define IDC_MAIN_SERVER_SCREENS_LABEL   1004
#define IDC_MAIN_SCREENS                1005
#define IDC_MAIN_OPTIONS                1006
#define IDC_MAIN_ADVANCED               1007
#define IDC_MAIN_AUTOSTART              1008
#define IDC_MAIN_TEST                   1009
#define IDC_MAIN_SAVE                   1010
#define IDC_MAIN_DEBUG                  1011
#define IDC_ADD_SCREEN_NAME_EDIT        1020
#define IDC_ADD_ALIASES_EDIT            1021
#define IDC_SCREENS_LEFT_COMBO          1022
#define IDC_SCREENS_RIGHT_COMBO         1023
#define IDC_SCREENS_TOP_COMBO           1024
#define IDC_SCREENS_BOTTOM_COMBO        1025
#define IDC_AUTOSTART_INSTALLED_MSG     1031
#define IDC_AUTOSTART_PERMISSION_MSG    1032
#define IDC_AUTOSTART_INSTALL_USER      1033
#define IDC_AUTOSTART_INSTALL_SYSTEM    1034
#define IDC_ADD_HD_CAPS_CHECK           1037
#define IDC_ADD_HD_NUM_CHECK            1038
#define IDC_ADVANCED_NAME_EDIT          1038
#define IDC_ADVANCED_PORT_EDIT          1039
#define IDC_ADD_HD_SCROLL_CHECK         1039
#define IDC_ADVANCED_INTERFACE_EDIT     1040
#define IDC_GLOBAL_DELAY_CHECK          1041
#define IDC_GLOBAL_DELAY_TIME           1042
#define IDC_GLOBAL_TWO_TAP_CHECK        1043
#define IDC_ADD_MOD_SHIFT               1043
#define IDC_GLOBAL_TWO_TAP_TIME         1044
#define IDC_ADD_MOD_CTRL                1044
#define IDC_ADD_MOD_ALT                 1045
#define IDC_GLOBAL_HEARTBEAT_CHECK      1045
#define IDC_ADD_MOD_META                1046
#define IDC_GLOBAL_HEARTBEAT_TIME       1046
#define IDC_ADD_MOD_SUPER               1047
#define IDC_GLOBAL_SCREENSAVER_SYNC     1047
#define IDC_GLOBAL_RELATIVE_MOVES       1048
#define IDC_ADVANCED_DEFAULTS           1049
#define IDC_GLOBAL_LEAVE_FOREGROUND     1049
#define IDC_ADD_DC_SIZE                 1052
#define IDC_ADD_DC_TOP_LEFT             1053
#define IDC_ADD_DC_TOP_RIGHT            1054
#define IDC_ADD_DC_BOTTOM_LEFT          1055
#define IDC_ADD_DC_BOTTOM_RIGHT         1056
#define IDC_SCREENS_SRC_SIDE            1057
#define IDC_SCREENS_SRC_START           1058
#define IDC_SCREENS_SRC_END             1059
#define IDC_SCREENS_SRC_SCREEN          1060
#define IDC_SCREENS_SCREENS             1061
#define IDC_SCREENS_ADD_SCREEN          1062
#define IDC_SCREENS_LINKS               1063
#define IDC_SCREENS_DST_START           1064
#define IDC_SCREENS_DST_END             1065
#define IDC_SCREENS_DST_SCREEN          1066
#define IDC_SCREENS_REMOVE_SCREEN       1067
#define IDC_SCREENS_EDIT_SCREEN         1068
#define IDC_SCREENS_ADD_LINK            1069
#define IDC_SCREENS_REMOVE_LINK         1070
#define IDC_SCREENS_OVERLAP_ERROR       1071

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        111
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1072
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
